@@ -35,25 +35,19 @@ from pycom import constants
 
 
 @pycom.interface(constants.IFACE_NAMESERVER)
-class NameServer(object):
+class NameServer(pycom.Service):
     """Class representing nameserver for PyCOM."""
 
+    # pylint: disable-msg=W0613,R0201
+
     @pycom.method(constants.NS_METHOD_STAT)
-    def method_stat(self, request):  # pylint: disable-msg=W0613,R0201
+    def method_stat(self, request):
         """Ping method. Will return some statistics in the future."""
         return {}
 
     @pycom.method(constants.NS_METHOD_REGISTER)
-    def method_register(self, request):
+    def method_register(self, request, address, interface, service):
         """Register service."""
-        try:
-            address = request.args["address"]
-            interface = request.args["interface"]
-            service = request.args["service"]
-        except (KeyError, TypeError):
-            raise pycom.BadRequest("Following field are mandatory: "
-                "address, interface, service")
-
         if interface not in self._registry:
             self._registry[interface] = []
 
@@ -64,21 +58,14 @@ class NameServer(object):
         return {}
 
     @pycom.method(constants.NS_METHOD_LOCATE)
-    def method_locate(self, request):
+    def method_locate(self, request, interface, service=None):
         """Locate service."""
-        try:
-            interface = request.args["interface"]
-        except (KeyError, TypeError):
-            raise pycom.BadRequest("Following field are mandatory: "
-                "interface")
-
         try:
             records = self._registry[interface]
         except KeyError:
             raise pycom.ServiceNotFound("Interface not found: %s" %
                 interface)
 
-        service = request.args.get("service")
         full_list = [
             {
                 "address": record.address,
@@ -96,7 +83,7 @@ class NameServer(object):
             return full_list[0]
 
     @pycom.method(constants.NS_METHOD_LIST_SERVICES)
-    def method_list_services(self, request):    # pylint: disable-msg=W0613
+    def method_list_services(self, request):
         """List all services."""
         return [
             {
@@ -106,6 +93,8 @@ class NameServer(object):
             for rec in itervalues(self._services)
         ]
 
+    # pylint: enable-msg=W0613,R0201
+
     # Private
 
     _registry = {}
