@@ -33,8 +33,8 @@ from optparse import OptionParser
 
 from six import iterkeys
 
-from . import base, constants, exceptions, interfaces, nsclient, utils
-from .zerojson import server
+from . import base, constants, exceptions, interfaces, nsclient
+from . import utils, zerojson
 
 
 def main(argv=None):
@@ -104,11 +104,11 @@ def main(argv=None):
             "service": service
         })
 
-    server.setup_ioloop(address)
+    zerojson.setup_ioloop(address)
 
     utils.logger().info("PyCOM v%s (service '%s' on '%s')",
         constants.__version__, service, address)
     try:
-        return server.ioloop().start()
+        return zerojson.ioloop().start()
     except KeyboardInterrupt:  # pragma: no cover
         utils.logger().info("Got KeyboardInterrupt, exiting")
