@@ -74,35 +74,3 @@ class ConfigureTest(BaseTest, unittest.TestCase):
 
         self.assertDictEqual(pycom.configuration,
             {"nameserver": "localhost3", "service": "/test/Test2"})
-
-
-class TestUUIDFactory(unittest.TestCase):
-
-    def testExisting(self):
-        factory = base.UUIDFactory(base.Session)
-        sessid = factory.new().session_id
-        self.assertTrue(sessid)
-
-        self.assertDictEqual(factory.get(sessid), {})
-        self.assertIsInstance(factory.get(sessid), base.Session)
-        self.assertEqual(factory.get(sessid).session_id, sessid)
-        self.assertIs(factory.get(sessid), factory.get(sessid))
-
-        factory.get(sessid)["item"] = 42
-
-        self.assertDictEqual(factory.get(sessid), {"item": 42})
-
-        factory = base.UUIDFactory(base.Call)
-        callid = factory.new().call_id
-        self.assertTrue(callid)
-
-        self.assertDictEqual(factory.get(callid), {})
-        self.assertIsInstance(factory.get(callid), base.Call)
-        self.assertEqual(factory.get(callid).call_id, callid)
-        self.assertIs(factory.get(callid), factory.get(callid))
-
-    def testNonExisting(self):
-        factory = base.UUIDFactory(base.Session)
-        self.assertRaises(KeyError, factory.get, "banana!")
-        factory = base.UUIDFactory(base.Call)
-        self.assertRaises(KeyError, factory.get, "banana!")
