@@ -52,8 +52,8 @@ class MainTest(BaseTest, unittest.TestCase):
         self.oldConf = base.configuration.copy()
         base.configuration.clear()
 
-        nsclient._tls.ns_component = \
-            pycom.apps.nameserver.NameServer().__interface__
+        nsclient._restore_cached_ns(
+            pycom.apps.nameserver.NameServer().__interface__)
 
     def tearDown(self):
         base.configuration.clear()
