@@ -42,12 +42,11 @@ class BaseTest(InterfacesBaseTest):
 
     def setUp(self):
         super(BaseTest, self).setUp()
-        self.oldNS = getattr(nsclient._tls, "ns_component", None)
-        nsclient._tls.ns_component = None
+        self.oldNS = nsclient._pop_cached_ns()
         pycom.configure(nameserver="local")
 
     def tearDown(self):
-        nsclient._tls.ns_component = self.oldNS
+        nsclient._restore_cached_ns(self.oldNS)
         super(BaseTest, self).tearDown()
 
 class LocalNSTest(BaseTest, unittest.TestCase):
@@ -98,7 +97,7 @@ def fake_container(context, event, addr, event2, handler):
 
         request = call_command.request_from_wire(body)
         sock.send_multipart([constants.PROTO_STATUS_SUCCESS,
-            call_command.response_to_wire(*handler(request))])
+            call_command.response_to_wire(handler(request))])
 
     sock.close()
 
@@ -109,9 +108,10 @@ def ns_handler(request):
         constants.NS_METHOD_STAT)
 
     if request.method == constants.NS_METHOD_STAT:
-        return 0, None, {}, None
+        return request.response({})
     else:
-        return constants.ERROR_SERVICE_NOT_FOUND, None, None, None
+        return pycom.Response(request,
+                code=constants.ERROR_SERVICE_NOT_FOUND)
 
 
 class RemoteNSTest(BaseTest, unittest.TestCase):
@@ -168,9 +168,9 @@ def ns_handler_w_error(request):
         constants.NS_METHOD_STAT)
 
     if request.method == constants.NS_METHOD_STAT:
-        return 0, None, {}, None
+        return request.response({})
     else:
-        return 100500, None, None, None
+        return pycom.Response(request, code=100500)
 
 
 class LocateFailureTest(BaseTest, unittest.TestCase):
@@ -210,16 +210,17 @@ def ns_handler2(request):
         constants.NS_METHOD_STAT)
 
     if request.method == constants.NS_METHOD_STAT:
-        return 0, None, {}, None
+        return request.response({})
     else:
         if request.args["interface"] == "iface.name":
             assert request.args.get("service") is None
-            return 0, None, {"address": "ipc://test_nsclient_h2"}, None
+            return request.response({"address": "ipc://test_nsclient_h2"})
         elif request.args["interface"] == "iface.name2":
             assert request.args["service"] == "service.name2"
-            return 0, None, {"address": "ipc://test_nsclient_h2"}, None
+            return request.response({"address": "ipc://test_nsclient_h2"})
         else:
-            return constants.ERROR_SERVICE_NOT_FOUND, None, None, None
+            return pycom.Response(request,
+                code=constants.ERROR_SERVICE_NOT_FOUND)
 
 
 class LocateTest(BaseTest, unittest.TestCase):
